Module: L43::Time::TimeCalc::Cli::Help

Extended by:
Help
Includes:
Color::Output
Included in:
Help
Defined in:
lib/l43/time/time_calc/cli/help.rb

Instance Method Summary collapse

Instance Method Details

#additional_help_information ⇒ Object



14
15
16
17
18
19
20
# File 'lib/l43/time/time_calc/cli/help.rb', line 14

def additional_help_information
  [
    ["prints the result of the calculations indicated by ", *_options("options"), " to ", :blue, "stdout"],
    ["the result is a time which is formatted according to the ", *_options("fmt:|f:"), " keyword"],
    [nil, 3, "the ", :bold, :blue, "<time-expr>", :reset, " positional arguments default to ", :bold, :magenta, "Time.now"],
  ].map { |line| [3, *line, :reset] }
end

#help_format ⇒ Object



10
# File 'lib/l43/time/time_calc/cli/help.rb', line 10

def help_format = _output(_help_formats)

#help_time_expression ⇒ Object



12
# File 'lib/l43/time/time_calc/cli/help.rb', line 12

def help_time_expression = _output(_help_time_expressions)